@@ -1,5 +1,6 @@
 import getopt
 import logging
+import os
 import sys
 import time
 import traceback
@@ -12,6 +13,7 @@ from ndu_gate_camera.camera.ndu_camera_service import NDUCameraService
 from ndu_gate_camera.camera.ndu_logger import NDULoggerHandler
 from ndu_gate_camera.camera.result_handlers.result_handler_file import ResultHandlerFile
 from ndu_gate_camera.camera.result_handlers.result_handler_socket import ResultHandlerSocket
+from ndu_gate_camera.camera.result_handlers.result_handler_mqtt import ResultHandlerMqtt
 from ndu_gate_camera.utility import onnx_helper
 from ndu_gate_camera.utility.constants import DEFAULT_NDU_GATE_CONF, DEFAULT_NDU_GATE_CONF_WIN, DEFAULT_HANDLER_SETTINGS
 from ndu_gate_camera.utility.ndu_utility import NDUUtility
@@ -30,13 +32,12 @@ def _get_config():
         except getopt.GetoptError:
             print('ndu_camera.py -c <config_file_path>')
 
+    if ndu_gate_config_file and path.sep not in ndu_gate_config_file:
+        ndu_gate_config_file = path.join(path.dirname(path.abspath(__file__)) + '/config/'.replace('/', path.sep),
+                                         ndu_gate_config_file)
+
     config_file_name = "ndu_gate.yaml"
     if ndu_gate_config_file is None:
-        config_file_name = "ndu_gate_debug.yaml"
-        import os
-        if os.environ.get('COMPUTERNAME', None) == "KORAY":
-            config_file_name = "ndu_gate_debug_koray.yaml"
-
         config_file = path.dirname(path.abspath(__file__)) + '/config/'.replace('/', path.sep) + config_file_name
         if path.isfile(config_file):
             ndu_gate_config_file = config_file
@@ -59,7 +60,8 @@ def main(ndu_gate_config_file):
 
     try:
         if ndu_gate_config_file is None:
-            ndu_gate_config_file = path.dirname(path.dirname(path.abspath(__file__))) + '/config/ndu_gate.yaml'.replace('/', path.sep)
+            ndu_gate_config_file = path.dirname(path.dirname(path.abspath(__file__))) + '/config/ndu_gate.yaml'.replace(
+                '/', path.sep)
 
         if not path.isfile(ndu_gate_config_file):
             print('config parameter is not a file : ', ndu_gate_config_file)
@@ -96,8 +98,16 @@ def main(ndu_gate_config_file):
         if result_hand_conf is None:
             result_hand_conf = DEFAULT_HANDLER_SETTINGS
 
-        if str(result_hand_conf.get("type", "SOCKET")) == str("SOCKET"):
-            result_handler = ResultHandlerSocket(result_hand_conf.get("socket", {}), result_hand_conf.get("device", None))
+        res_handler = result_hand_conf.get("type")
+
+        if str(res_handler) == str("SOCKET"):
+            result_handler = ResultHandlerSocket(result_hand_conf.get("socket", {}),
+                                                 result_hand_conf.get("device", None))
+        elif res_handler == str("MQTT"):
+            print('RESULT HANDLER IS MQTT!!!')
+            result_handler = ResultHandlerMqtt(result_hand_conf.get("access_token"), result_hand_conf.get("mqtt"))
+        elif str(res_handler) == str("FILE"):
+            result_handler = ResultHandlerFile(result_hand_conf.get("file_path", None))
         else:
             result_handler = ResultHandlerFile(result_hand_conf.get("file_path", None))
 
@@ -106,9 +116,13 @@ def main(ndu_gate_config_file):
             services = []
             preview_exists = False
             for instance in instances:
+                if instance["source"].get("ignore", True):
+                    continue
                 if instance["source"].get("preview_show", False):
                     preview_exists = True
-                camera_service = NDUCameraService(instance=instance, config_dir=ndu_gate_config_dir, handler=result_handler, is_main_thread=False, extension_folder=extension_folder)
+                camera_service = NDUCameraService(instance=instance, config_dir=ndu_gate_config_dir,
+                                                  handler=result_handler, is_main_thread=False,
+                                                  extension_folder=extension_folder)
                 camera_service.start()
                 services.append(camera_service)
                 log.info("NDU-Gate an instance started")
@@ -128,8 +142,10 @@ def main(ndu_gate_config_file):
             else:
                 for service in services:
                     service.join()
-        elif len(instances) == 1:
-            camera_service = NDUCameraService(instance=instances[0], config_dir=ndu_gate_config_dir, handler=result_handler, is_main_thread=True, extension_folder=extension_folder)
+        elif len(instances) == 1 and instances[0]["source"].get("ignore", True) is False:
+            camera_service = NDUCameraService(instance=instances[0], config_dir=ndu_gate_config_dir,
+                                              handler=result_handler, is_main_thread=True,
+                                              extension_folder=extension_folder)
             camera_service.run()
         else:
             log.error("NDUCameraService no source found!")
